%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%
%  %NAME%    : Classe permettant l'criture rapide d'un rapport type
%              rapport de stage en francais
%  %AUTHOR%  : Guillaume Pinot
%  %EMAIL%   : guillaume.pinot@tremplin-utc.net
%  %VERSION% : 0.1 (16/03/2005)
%
%    Copyright (C) Guillaume Pinot
%    
%    This program is free software; you can redistribute it and/or
%    modify it under the terms of the GNU General Public License
%    as published by the Free Software Foundation; either version 2
%    of the License, or (at your option) any later version.
%    
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%    
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
%
%
%    The GNU General Public License can be found on the website
%    http://www.fsf.org
%    
%    Les travaux de traduction de la GPL peuvent tre trouvs sur le
%    site : http://www.april.org/gnu/gpl_french.html
%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% Cette classe est inspire de beaucoup d'autres classes et styles glans sur 
%   internet ainsi que de solutions apportes dans les newsgroup (comp.text.tex
%   et fr.comp.text.tex) et dans les FAQ en tout genre.
%
% Merci particulierement  Virginie Quesnay pour sa classe rapportiut
%   qui m'a inspir
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
\ProvidesClass{rapport}[2005/03/16 v0.1 rapport class Guillaume Pinot]
\NeedsTeXFormat{LaTeX2e}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Les if utilis pour le package :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Test pour voir si on utilise pdflatex
\newif\ifpdf
\ifx\pdfoutput\undefined
  \pdffalse   % we are not running PDFLaTeX
\else
  \pdfoutput=1  % we are running PDFLaTeX
  \pdftrue
\fi
%% Test pour savoir si on veux les liens en noir:
\newif\ifBlacklinks\Blacklinksfalse

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% On veut pouvoir avoir des options :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Option pour avoir les liens en noir en pdf
\DeclareOption{blacklinks}{\Blacklinkstrue}
%% si l'option n'est pas une cre par moi, la passer  book
\DeclareOption*{%
      \PassOptionsToClass{\CurrentOption}{book}}
%% on execute ensuite les options passes par l'utilisateur
\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Charger la classe book :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\LoadClass[11pt,a4paper,oneside]{book}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Les commandes d'infos complmentaires :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% La date
\def\date#1{\gdef\@date{\\{\large #1}}}
\gdef\@date{}
%% Le suiveur
\def\suiveur#1{\gdef\@suiveur{\\{\large Suiveur : #1}}}
\gdef\@suiveur{}
%% L'anne
\def\authoryear#1{\gdef\@authoryear{\\{\large #1}}}
\gdef\@authoryear{}
%% Logo cole
\def\logoecole#1{\gdef\@logoecole{%
    \includegraphics[width=\linewidth]{#1}}}
\gdef\@logoecole{}
%% sous-titre
\def\subtitle#1{\gdef\@subtitle{\\ {\Huge #1\\ }\strut}}
\gdef\@subtitle{}
%% Logo entreprise
\def\logoentreprise#1{\gdef\@logoentreprise{%
    \includegraphics[width=\linewidth]{#1}}}
\gdef\@logoentreprise{}
%% infos entreprise
\def\infosentreprise#1{\gdef\@infosentreprise{#1}}
\gdef\@infosentreprise{}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Les Packages :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[T1]{fontenc}
\RequirePackage[cyr]{aeguill}
\RequirePackage{graphicx}
\RequirePackage[latin1]{inputenc}
\RequirePackage{indentfirst}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Les personnalisations :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% redfinition de \and pour la classe
\def\and{\qquad}

%% Gestion des options du pdf avec l'option blacklinks
\ifpdf
    \ifBlacklinks
      \RequirePackage[plainpages=false,pdfpagelabels,%
        pdftex,colorlinks,hypertexnames=true,%
        citecolor=black,linkcolor=black,urlcolor=black]{hyperref}
    \else
      \RequirePackage[plainpages=false,pdfpagelabels,%
        pdftex,colorlinks,hypertexnames=true,%
        citecolor=blue,linkcolor=blue,urlcolor=blue]{hyperref}
    \fi
\else
  \def\url#1{#1}
\fi

%% La commande qui n'est bien pour les urls.
\DeclareRobustCommand{\texturl}{%
  \begingroup\catcode`\:=11\relax\catcode`\?=11\relax%
  \catcode`\&=11\relax%
  \catcode`\~=11\relax\catcode`\_=11\relax\texturL}
\def\texturL#1{\texttt{\url{#1}}\endgroup}

%% Personnalisation des paragraphes
\renewcommand\paragraph{
  \@startsection{paragraph}{4}{\z@}%
  {3.25ex \@plus1ex \@minus.2ex}%
  {.1em}%
  {\normalfont\normalsize\bfseries}}

%% Redfinition de appendix pour avoir la numrotation malgrs \backmatter
\renewcommand\appendix{\par
  \setcounter{chapter}{0}%
  \setcounter{section}{0}%
  \@mainmattertrue
  \gdef\@chapapp{\appendixname}%
  \gdef\thechapter{\@Alph\c@chapter}}

%% Une demi espace inscable avant la footnote comme ont doit faire en francais
\let\Footnote\footnote
\def\footnote{\,\Footnote}

%% petites capitales grasses, mais c'est pas en vectoriel. C'est pas
%% beau sous acroread < 6 (xpdf 3, par contre, ca passe tres bien),
%% mais ca passe bien  l'impression. Pour avoir des petites
%% capitales non grasses a la place de petites capitales grasses, mais
%% en vectoriel, changer avec la ligne du dessous.
\DeclareFontShape{T1}{aer}{bx}{sc}{<->sub * cmr/bx/sc}{}
%%\DeclareFontShape{T1}{aer}{bx}{sc}{<->sub * aer/n/sc}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Le maketitle :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\maketitle{
  \begin{titlepage}
    \renewcommand{\thepage}{title}
    \noindent
    \begin{minipage}{8cm}
      {\large \@author}
      \@authoryear
      \@suiveur
      \@date
    \end{minipage}
    \hfill
    \begin{minipage}{.3\linewidth}
      \@logoecole
    \end{minipage}
    \vskip 1.5ex
    \noindent\rule{\linewidth}{.5pt}

    \vspace{\fill}

    \noindent\rule{\linewidth}{1mm}

    \begin{center}
      \strut\\
      {\huge {\bf \@title}} \\
      \strut
      \@subtitle
    \end{center}

    \noindent\rule{\linewidth}{1mm}

    \vspace{\fill}

    \noindent
    \begin{minipage}{.3\linewidth}
      \@logoentreprise
    \end{minipage}
    \hfill
    \begin{minipage}{.55\linewidth}
      \noindent
      \@infosentreprise
    \end{minipage}
    \@thanks
  \end{titlepage}
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax

  \gdef\date{}
  \gdef\@date{}
  \gdef\suiveur{}
  \gdef\@suiveur{}
  \gdef\authoryear{}
  \gdef\@authoryear{}
  \gdef\logoecole{}
  \gdef\@logoecole{}
  \gdef\subtitle{}
  \gdef\@subtitle{}
  \def\logoentreprise{}
  \gdef\@logoentreprise{}
  \def\infosentreprise{}
  \gdef\@infosentreprise{}

}
